==> PyTrinamic-0.0.10-py3-none-any.whl: PyTrinamic/examples/evalboards/TMC4672_eval_register_dump.py <==
'''
Created on 09.01.2019

@author: LK
'''

if __name__ == '__main__':
    pass

import PyTrinamic
from PyTrinamic.connections.serial_tmcl_interface import serial_tmcl_interface
from PyTrinamic.evalboards.TMC4672_eval import TMC4672_eval
#from PyTrinamic.ic.TMC4672.TMC4672_register import TMC4672_register
#from PyTrinamic.ic.TMC4672.TMC4672_mask_shift import TMC4672_mask_shift

PyTrinamic.showInfo()
PyTrinamic.showAvailableComPorts()

myInterface = serial_tmcl_interface('COM3')
tmc4672_eval = TMC4672_eval(myInterface)
tmc4672_eval.showChipInfo()

tmc4672_reg = tmc4672_eval.registers
tmc4672_ms = tmc4672_eval.mask_shift

print("CHIPINFO_DATA: ")
print(myInterface.readMC(tmc4672_reg.CHIPINFO_DATA).value)
print("CHIPINFO_ADDR: ")
print(myInterface.readMC(tmc4672_reg.CHIPINFO_ADDR).value)
print("ADC_RAW_DATA: ")
print(myInterface.readMC(tmc4672_reg.ADC_RAW_DATA).value)
print("ADC_RAW_ADDR: ")
print(myInterface.readMC(tmc4672_reg.ADC_RAW_ADDR).value)
print("ADC_CONFIG_DATA: ")
print(myInterface.readMC(tmc4672_reg.ADC_CONFIG_DATA).value)
print("ADC_CONFIG_ADDR: ")
print(myInterface.readMC(tmc4672_reg.ADC_CONFIG_ADDR).value)
print("ADC_IWY_IUX: ")
print(myInterface.readMC(tmc4672_reg.ADC_IWY_IUX).value)
print("ADC_IV_VM: ")
print(myInterface.readMC(tmc4672_reg.ADC_IV_VM).value)
print("AENC_WY_UX: ")
print(myInterface.readMC(tmc4672_reg.AENC_WY_UX).value)
print("AENC_VN: ")
print(myInterface.readMC(tmc4672_reg.AENC_VN).value)
print("PWM_POLARITIES: ")
print(myInterface.readMC(tmc4672_reg.PWM_POLARITIES).value)
print("PWM_MAXCOUNT: ")
print(myInterface.readMC(tmc4672_reg.PWM_MAXCOUNT).value)
print("PWM_BBM_H_BBM_L: ")
print(myInterface.readMC(tmc4672_reg.PWM_BBM_H_BBM_L).value)
print("PWM_SV_CHOP: ")
print(myInterface.readMC(tmc4672_reg.PWM_SV_CHOP).value)
print("MOTOR_TYPE_N_POLE_PAIRS: ")
print(myInterface.readMC(tmc4672_reg.MOTOR_TYPE_N_POLE_PAIRS).value)
print("ADC_I1_I0_EXT: ")
print(myInterface.readMC(tmc4672_reg.ADC_I1_I0_EXT).value)
print("PHI_E_EXT: ")
print(myInterface.readMC(tmc4672_reg.PHI_E_EXT).value)
print("PHI_M_EXT: ")
print(myInterface.readMC(tmc4672_reg.PHI_M_EXT).value)
print("POSITION_EXT: ")
print(myInterface.readMC(tmc4672_reg.POSITION_EXT).value)
print("OPENLOOP_MODE: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_MODE).value)
print("OPENLOOP_ACCELERATION: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_ACCELERATION).value)
print("OPENLOOP_VELOCITY_TARGET: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_VELOCITY_TARGET).value)
print("OPENLOOP_VELOCITY_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_VELOCITY_ACTUAL).value)
print("PHI_OPENLOOP: ")
print(myInterface.readMC(tmc4672_reg.PHI_OPENLOOP).value)
print("UQ_UD_EXT: ")
print(myInterface.readMC(tmc4672_reg.UQ_UD_EXT).value)
print("POS_FB_CONFIG_DATA: ")
print(myInterface.readMC(tmc4672_reg.POS_FB_CONFIG_DATA).value)
print("POS_FB_CONFIG_ADDR: ")
print(myInterface.readMC(tmc4672_reg.POS_FB_CONFIG_ADDR).value)
print("CONFIG_DATA: ")
print(myInterface.readMC(tmc4672_reg.CONFIG_DATA).value)
print("CONFIG_ADDR: ")
print(myInterface.readMC(tmc4672_reg.CONFIG_ADDR).value)
print("ABN_DECODER_COUNT: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_COUNT).value)
print("ABN_DECODER_COUNT_N: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_COUNT_N).value)
print("ABN_DECODER_PHI_E_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_PHI_E_PHI_M).value)
print("ABN_DECODER_POSITION: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_POSITION).value)
print("ABN_2_DECODER_COUNT: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_COUNT).value)
print("ABN_2_DECODER_COUNT_N: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_COUNT_N).value)
print("ABN_2_DECODER_PHI_E_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_PHI_E_PHI_M).value)
print("ABN_2_DECODER_POSITION: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_POSITION).value)
print("HALL_PHI_E_INTERPOLATED_PHI_E: ")
print(myInterface.readMC(tmc4672_reg.HALL_PHI_E_INTERPOLATED_PHI_E).value)
print("HALL_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.HALL_PHI_M).value)
print("AENC_DECODER_COUNT: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_COUNT).value)
print("AENC_DECODER_COUNT_N: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_COUNT_N).value)
print("AENC_DECODER_PHI_E_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_PHI_E_PHI_M).value)
print("AENC_DECODER_POSITION: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_POSITION).value)
print("RAMP_STATUS: ")
print(myInterface.readMC(tmc4672_reg.RAMP_STATUS).value)
print("RAMP_AMAX_A1: ")
print(myInterface.readMC(tmc4672_reg.RAMP_AMAX_A1).value)
print("RAMP_DMAX_D1: ")
print(myInterface.readMC(tmc4672_reg.RAMP_DMAX_D1).value)
print("RAMP_VSTART: ")
print(myInterface.readMC(tmc4672_reg.RAMP_VSTART).value)
print("RAMP_V1: ")
print(myInterface.readMC(tmc4672_reg.RAMP_V1).value)
print("RAMP_VSTOP: ")
print(myInterface.readMC(tmc4672_reg.RAMP_VSTOP).value)
print("RAMP_TZEROWAIT_SWITCHMODE: ")
print(myInterface.readMC(tmc4672_reg.RAMP_TZEROWAIT_SWITCHMODE).value)
print("RAMP_X_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.RAMP_X_ACTUAL).value)
print("RAMP_V_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.RAMP_V_ACTUAL).value)
print("RAMP_X_TARGET: ")
print(myInterface.readMC(tmc4672_reg.RAMP_X_TARGET).value)
print("RAMP_V_FEEDFORWARD: ")
print(myInterface.readMC(tmc4672_reg.RAMP_V_FEEDFORWARD).value)
print("OBSERVER_R_S_L_S_CROSS: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_R_S_L_S_CROSS).value)
print("OBSERVER_L_SD_L_SQ: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_L_SD_L_SQ).value)
print("OBSERVER_K_EMF_INV_K_FILT: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_K_EMF_INV_K_FILT).value)
print("OBSERVER_K_D: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_K_D).value)
print("OBSERVER_E_SD: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_E_SD).value)
print("OBSERVER_E_SQ: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_E_SQ).value)
print("OBSERVER_VELOCITY: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_VELOCITY).value)
print("OBSERVER_PHI_E: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_PHI_E).value)
print("VELOCITY_SELECTION: ")
print(myInterface.readMC(tmc4672_reg.VELOCITY_SELECTION).value)
print("POSITION_SELECTION: ")
print(myInterface.readMC(tmc4672_reg.POSITION_SELECTION).value)
print("PHI_E_SELECTION: ")
print(myInterface.readMC(tmc4672_reg.PHI_E_SELECTION).value)
print("PHI_E: ")
print(myInterface.readMC(tmc4672_reg.PHI_E).value)
print("PID_FLUX_P_FLUX_I: ")
print(myInterface.readMC(tmc4672_reg.PID_FLUX_P_FLUX_I).value)
print("PID_TORQUE_P_TORQUE_I: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_P_TORQUE_I).value)
print("PID_VELOCITY_P_VELOCITY_I: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_P_VELOCITY_I).value)
print("PID_POSITION_P_POSITION_I: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_P_POSITION_I).value)
print("PID_TYPE: ")
print(myInterface.readMC(tmc4672_reg.PID_TYPE).value)
print("PIDOUT_UQ_UD_LIMITS: ")
print(myInterface.readMC(tmc4672_reg.PIDOUT_UQ_UD_LIMITS).value)
print("PID_TORQUE_FLUX_LIMITS: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_LIMITS).value)
print("PID_ACCELERATION_LIMIT: ")
print(myInterface.readMC(tmc4672_reg.PID_ACCELERATION_LIMIT).value)
print("PID_VELOCITY_LIMIT: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_LIMIT).value)
print("PID_POSITION_LIMIT_LOW: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_LIMIT_LOW).value)
print("PID_POSITION_LIMIT_HIGH: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_LIMIT_HIGH).value)
print("MODE_RAMP_MODE_MOTION: ")
print(myInterface.readMC(tmc4672_reg.MODE_RAMP_MODE_MOTION).value)
print("PID_TORQUE_FLUX_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_TARGET).value)
print("PID_TORQUE_FLUX_OFFSET: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_OFFSET).value)
print("PIDIN_TORQUE_FLUX_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PIDIN_TORQUE_FLUX_TARGET).value)
print("PID_VELOCITY_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_TARGET).value)
print("PID_VELOCITY_OFFSET: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_OFFSET).value)
print("PIDIN_VELOCITY_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PIDIN_VELOCITY_TARGET).value)
print("PID_POSITION_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_TARGET).value)
print("PID_TORQUE_FLUX_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_ACTUAL).value)
print("PID_VELOCITY_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_ACTUAL).value)
print("PID_POSITION_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_ACTUAL).value)
print("PID_ERROR_DATA: ")
print(myInterface.readMC(tmc4672_reg.PID_ERROR_DATA).value)
print("PID_ERROR_ADDR: ")
print(myInterface.readMC(tmc4672_reg.PID_ERROR_ADDR).value)
print("INTERIM_DATA: ")
print(myInterface.readMC(tmc4672_reg.INTERIM_DATA).value)
print("INTERIM_ADDR: ")
print(myInterface.readMC(tmc4672_reg.INTERIM_ADDR).value)
print("WATCHDOG_CFG: ")
print(myInterface.readMC(tmc4672_reg.WATCHDOG_CFG).value)
print("ADC_VM_LIMITS: ")
print(myInterface.readMC(tmc4672_reg.ADC_VM_LIMITS).value)
print("INPUTS_RAW: ")
print(myInterface.readMC(tmc4672_reg.INPUTS_RAW).value)
print("OUTPUTS_RAW: ")
print(myInterface.readMC(tmc4672_reg.OUTPUTS_RAW).value)
print("STEP_WIDTH: ")
print(myInterface.readMC(tmc4672_reg.STEP_WIDTH).value)
print("UART_BPS: ")
print(myInterface.readMC(tmc4672_reg.UART_BPS).value)
print("UART_ADDRS: ")
print(myInterface.readMC(tmc4672_reg.UART_ADDRS).value)
print("GPIO_dsADCI_CONFIG: ")
print(myInterface.readMC(tmc4672_reg.GPIO_dsADCI_CONFIG).value)
print("STATUS_FLAGS: ")
print(myInterface.readMC(tmc4672_reg.STATUS_FLAGS).value)
print("STATUS_MASK: ")
print(myInterface.readMC(tmc4672_reg.STATUS_MASK).value)

" unpower "
print("unpowered...")
myInterface.writeMC(tmc4672_reg.UQ_UD_EXT, 0)

myInterface.close()

==> PyTrinamic-0.0.11-py3-none-any.whl: PyTrinamic/examples/evalboards/TMC4672_eval_register_dump.py <==
'''
Created on 09.01.2019

@author: LK
'''

if __name__ == '__main__':
    pass

import PyTrinamic
from PyTrinamic.connections.serial_tmcl_interface import serial_tmcl_interface
from PyTrinamic.evalboards.TMC4672_eval import TMC4672_eval
from PyTrinamic.ic.TMC4672.TMC4672_register import TMC4672_register
from PyTrinamic.ic.TMC4672.TMC4672_mask_shift import TMC4672_mask_shift

PyTrinamic.showInfo()
PyTrinamic.showAvailableComPorts()

myInterface = serial_tmcl_interface('COM5')
tmc4672_eval = TMC4672_eval(myInterface)
tmc4672_eval.showChipInfo()

tmc4672_reg = TMC4672_register()
tmc4672_ms = TMC4672_mask_shift()

print("CHIPINFO_DATA: ")
print(myInterface.readMC(tmc4672_reg.CHIPINFO_DATA).value)
print("CHIPINFO_ADDR: ")
print(myInterface.readMC(tmc4672_reg.CHIPINFO_ADDR).value)
print("ADC_RAW_DATA: ")
print(myInterface.readMC(tmc4672_reg.ADC_RAW_DATA).value)
print("ADC_RAW_ADDR: ")
print(myInterface.readMC(tmc4672_reg.ADC_RAW_ADDR).value)
print("ADC_CONFIG_DATA: ")
print(myInterface.readMC(tmc4672_reg.ADC_CONFIG_DATA).value)
print("ADC_CONFIG_ADDR: ")
print(myInterface.readMC(tmc4672_reg.ADC_CONFIG_ADDR).value)
print("ADC_IWY_IUX: ")
print(myInterface.readMC(tmc4672_reg.ADC_IWY_IUX).value)
print("ADC_IV_VM: ")
print(myInterface.readMC(tmc4672_reg.ADC_IV_VM).value)
print("AENC_WY_UX: ")
print(myInterface.readMC(tmc4672_reg.AENC_WY_UX).value)
print("AENC_VN: ")
print(myInterface.readMC(tmc4672_reg.AENC_VN).value)
print("PWM_POLARITIES: ")
print(myInterface.readMC(tmc4672_reg.PWM_POLARITIES).value)
print("PWM_MAXCOUNT: ")
print(myInterface.readMC(tmc4672_reg.PWM_MAXCOUNT).value)
print("PWM_BBM_H_BBM_L: ")
print(myInterface.readMC(tmc4672_reg.PWM_BBM_H_BBM_L).value)
print("PWM_SV_CHOP: ")
print(myInterface.readMC(tmc4672_reg.PWM_SV_CHOP).value)
print("MOTOR_TYPE_N_POLE_PAIRS: ")
print(myInterface.readMC(tmc4672_reg.MOTOR_TYPE_N_POLE_PAIRS).value)
print("ADC_I1_I0_EXT: ")
print(myInterface.readMC(tmc4672_reg.ADC_I1_I0_EXT).value)
print("PHI_E_EXT: ")
print(myInterface.readMC(tmc4672_reg.PHI_E_EXT).value)
print("PHI_M_EXT: ")
print(myInterface.readMC(tmc4672_reg.PHI_M_EXT).value)
print("POSITION_EXT: ")
print(myInterface.readMC(tmc4672_reg.POSITION_EXT).value)
print("OPENLOOP_MODE: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_MODE).value)
print("OPENLOOP_ACCELERATION: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_ACCELERATION).value)
print("OPENLOOP_VELOCITY_TARGET: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_VELOCITY_TARGET).value)
print("OPENLOOP_VELOCITY_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.OPENLOOP_VELOCITY_ACTUAL).value)
print("PHI_OPENLOOP: ")
print(myInterface.readMC(tmc4672_reg.PHI_OPENLOOP).value)
print("UQ_UD_EXT: ")
print(myInterface.readMC(tmc4672_reg.UQ_UD_EXT).value)
print("POS_FB_CONFIG_DATA: ")
print(myInterface.readMC(tmc4672_reg.POS_FB_CONFIG_DATA).value)
print("POS_FB_CONFIG_ADDR: ")
print(myInterface.readMC(tmc4672_reg.POS_FB_CONFIG_ADDR).value)
print("CONFIG_DATA: ")
print(myInterface.readMC(tmc4672_reg.CONFIG_DATA).value)
print("CONFIG_ADDR: ")
print(myInterface.readMC(tmc4672_reg.CONFIG_ADDR).value)
print("ABN_DECODER_COUNT: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_COUNT).value)
print("ABN_DECODER_COUNT_N: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_COUNT_N).value)
print("ABN_DECODER_PHI_E_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_PHI_E_PHI_M).value)
print("ABN_DECODER_POSITION: ")
print(myInterface.readMC(tmc4672_reg.ABN_DECODER_POSITION).value)
print("ABN_2_DECODER_COUNT: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_COUNT).value)
print("ABN_2_DECODER_COUNT_N: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_COUNT_N).value)
print("ABN_2_DECODER_PHI_E_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_PHI_E_PHI_M).value)
print("ABN_2_DECODER_POSITION: ")
print(myInterface.readMC(tmc4672_reg.ABN_2_DECODER_POSITION).value)
print("HALL_PHI_E_INTERPOLATED_PHI_E: ")
print(myInterface.readMC(tmc4672_reg.HALL_PHI_E_INTERPOLATED_PHI_E).value)
print("HALL_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.HALL_PHI_M).value)
print("AENC_DECODER_COUNT: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_COUNT).value)
print("AENC_DECODER_COUNT_N: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_COUNT_N).value)
print("AENC_DECODER_PHI_E_PHI_M: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_PHI_E_PHI_M).value)
print("AENC_DECODER_POSITION: ")
print(myInterface.readMC(tmc4672_reg.AENC_DECODER_POSITION).value)
print("RAMP_STATUS: ")
print(myInterface.readMC(tmc4672_reg.RAMP_STATUS).value)
print("RAMP_AMAX_A1: ")
print(myInterface.readMC(tmc4672_reg.RAMP_AMAX_A1).value)
print("RAMP_DMAX_D1: ")
print(myInterface.readMC(tmc4672_reg.RAMP_DMAX_D1).value)
print("RAMP_VSTART: ")
print(myInterface.readMC(tmc4672_reg.RAMP_VSTART).value)
print("RAMP_V1: ")
print(myInterface.readMC(tmc4672_reg.RAMP_V1).value)
print("RAMP_VSTOP: ")
print(myInterface.readMC(tmc4672_reg.RAMP_VSTOP).value)
print("RAMP_TZEROWAIT_SWITCHMODE: ")
print(myInterface.readMC(tmc4672_reg.RAMP_TZEROWAIT_SWITCHMODE).value)
print("RAMP_X_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.RAMP_X_ACTUAL).value)
print("RAMP_V_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.RAMP_V_ACTUAL).value)
print("RAMP_X_TARGET: ")
print(myInterface.readMC(tmc4672_reg.RAMP_X_TARGET).value)
print("RAMP_V_FEEDFORWARD: ")
print(myInterface.readMC(tmc4672_reg.RAMP_V_FEEDFORWARD).value)
print("OBSERVER_R_S_L_S_CROSS: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_R_S_L_S_CROSS).value)
print("OBSERVER_L_SD_L_SQ: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_L_SD_L_SQ).value)
print("OBSERVER_K_EMF_INV_K_FILT: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_K_EMF_INV_K_FILT).value)
print("OBSERVER_K_D: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_K_D).value)
print("OBSERVER_E_SD: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_E_SD).value)
print("OBSERVER_E_SQ: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_E_SQ).value)
print("OBSERVER_VELOCITY: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_VELOCITY).value)
print("OBSERVER_PHI_E: ")
print(myInterface.readMC(tmc4672_reg.OBSERVER_PHI_E).value)
print("VELOCITY_SELECTION: ")
print(myInterface.readMC(tmc4672_reg.VELOCITY_SELECTION).value)
print("POSITION_SELECTION: ")
print(myInterface.readMC(tmc4672_reg.POSITION_SELECTION).value)
print("PHI_E_SELECTION: ")
print(myInterface.readMC(tmc4672_reg.PHI_E_SELECTION).value)
print("PHI_E: ")
print(myInterface.readMC(tmc4672_reg.PHI_E).value)
print("PID_FLUX_P_FLUX_I: ")
print(myInterface.readMC(tmc4672_reg.PID_FLUX_P_FLUX_I).value)
print("PID_TORQUE_P_TORQUE_I: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_P_TORQUE_I).value)
print("PID_VELOCITY_P_VELOCITY_I: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_P_VELOCITY_I).value)
print("PID_POSITION_P_POSITION_I: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_P_POSITION_I).value)
print("PID_TYPE: ")
print(myInterface.readMC(tmc4672_reg.PID_TYPE).value)
print("PIDOUT_UQ_UD_LIMITS: ")
print(myInterface.readMC(tmc4672_reg.PIDOUT_UQ_UD_LIMITS).value)
print("PID_TORQUE_FLUX_LIMITS: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_LIMITS).value)
print("PID_ACCELERATION_LIMIT: ")
print(myInterface.readMC(tmc4672_reg.PID_ACCELERATION_LIMIT).value)
print("PID_VELOCITY_LIMIT: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_LIMIT).value)
print("PID_POSITION_LIMIT_LOW: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_LIMIT_LOW).value)
print("PID_POSITION_LIMIT_HIGH: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_LIMIT_HIGH).value)
print("MODE_RAMP_MODE_MOTION: ")
print(myInterface.readMC(tmc4672_reg.MODE_RAMP_MODE_MOTION).value)
print("PID_TORQUE_FLUX_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_TARGET).value)
print("PID_TORQUE_FLUX_OFFSET: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_OFFSET).value)
print("PIDIN_TORQUE_FLUX_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PIDIN_TORQUE_FLUX_TARGET).value)
print("PID_VELOCITY_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_TARGET).value)
print("PID_VELOCITY_OFFSET: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_OFFSET).value)
print("PIDIN_VELOCITY_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PIDIN_VELOCITY_TARGET).value)
print("PID_POSITION_TARGET: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_TARGET).value)
print("PID_TORQUE_FLUX_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.PID_TORQUE_FLUX_ACTUAL).value)
print("PID_VELOCITY_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.PID_VELOCITY_ACTUAL).value)
print("PID_POSITION_ACTUAL: ")
print(myInterface.readMC(tmc4672_reg.PID_POSITION_ACTUAL).value)
print("PID_ERROR_DATA: ")
print(myInterface.readMC(tmc4672_reg.PID_ERROR_DATA).value)
print("PID_ERROR_ADDR: ")
print(myInterface.readMC(tmc4672_reg.PID_ERROR_ADDR).value)
print("INTERIM_DATA: ")
print(myInterface.readMC(tmc4672_reg.INTERIM_DATA).value)
print("INTERIM_ADDR: ")
print(myInterface.readMC(tmc4672_reg.INTERIM_ADDR).value)
print("WATCHDOG_CFG: ")
print(myInterface.readMC(tmc4672_reg.WATCHDOG_CFG).value)
print("ADC_VM_LIMITS: ")
print(myInterface.readMC(tmc4672_reg.ADC_VM_LIMITS).value)
print("INPUTS_RAW: ")
print(myInterface.readMC(tmc4672_reg.INPUTS_RAW).value)
print("OUTPUTS_RAW: ")
print(myInterface.readMC(tmc4672_reg.OUTPUTS_RAW).value)
print("STEP_WIDTH: ")
print(myInterface.readMC(tmc4672_reg.STEP_WIDTH).value)
print("UART_BPS: ")
print(myInterface.readMC(tmc4672_reg.UART_BPS).value)
print("UART_ADDRS: ")
print(myInterface.readMC(tmc4672_reg.UART_ADDRS).value)
print("GPIO_dsADCI_CONFIG: ")
print(myInterface.readMC(tmc4672_reg.GPIO_dsADCI_CONFIG).value)
print("STATUS_FLAGS: ")
print(myInterface.readMC(tmc4672_reg.STATUS_FLAGS).value)
print("STATUS_MASK: ")
print(myInterface.readMC(tmc4672_reg.STATUS_MASK).value)

" unpower "
print("unpowered...")
myInterface.writeMC(tmc4672_reg.UQ_UD_EXT, 0)

myInterface.close()
